@@ -40,7 +40,7 @@ class KColumnFilterProxyModel : public QSortFilterProxyModel
     Q_OBJECT
 public:
     explicit KColumnFilterProxyModel(QObject *parent = nullptr);
-    virtual ~KColumnFilterProxyModel();
+    ~KColumnFilterProxyModel() override;
 
     /**
       Returns a vector containing the visible columns. If the vector is empy, all
@@ -68,8 +68,7 @@ protected:
     bool filterAcceptsColumn(int column, const QModelIndex &parent) const override;
 
 private:
-    KColumnFilterProxyModelPrivate *const d_ptr;
-    Q_DECLARE_PRIVATE(KColumnFilterProxyModel)
+    QVector<int> m_visibleColumns;
 };
 
 }
